<template>
    <div class="form-group">
        <label v-if="label" :for="id" :class="labelClass">
            {{ label }}
        </label>
        <select
            :id="id"
            :name="name"
            :class="['form-control', inputClass, { 'is-invalid': errorMessage }]"
            :value="modelValue"
            @change="updateValue"
        >
            <option v-if="placeholder" value="" disabled>{{ placeholder }}</option>
            <option v-for="option in options" :key="option.value" :value="option.value">
                {{ option.label }}
            </option>
        </select>
        <span v-if="errorMessage" class="invalid-feedback">{{ errorMessage }}</span>
    </div>
</template>

<script setup>
import { defineProps, defineEmits } from 'vue';

const props = defineProps({
    label: String,
    name: { type: String, default: '' },
    id: { type: String, default: '' },
    labelClass: { type: String, default: '' },
    inputClass: { type: String, default: '' },
    modelValue: { type: [String, Number], default: '' },
    placeholder: { type: String, default: 'Select an option' },
    errorMessage: { type: String, default: '' },
    options: {
        type: Array,
        default: () => [],
        validator: (value) => value.every(opt => 'label' in opt && 'value' in opt)
    }
});

const emit = defineEmits(['update:modelValue']);

const updateValue = (event) => {
    emit('update:modelValue', event.target.value);
};
</script>
